# xxp

## What

It's [`xxd`][xxddoc] ([C source][xxdsrc]), but in Python, so it can also provide an API. Helpful when trying to reverse engineer binary things.

## Why

Part created for a want of a Python binary-dumper to decode my LoRa messages, part to learn GitHub Actions.


[xxddoc]: https://linux.die.net/man/1/xxd
[xxdsrc]: https://github.com/vim/vim/blob/master/src/xxd/xxd.c
